@@ -125,7 +125,7 @@ weightedMedian <- function(x, w=NULL, idxs=NULL, na.rm=FALSE, interpolate=is.nul
     }
   }
 
-  .Call("weightedMedian", x, w, idxs, na.rm, interpolate, tiesC, package="matrixStats")
+  .Call(C_weightedMedian, x, w, idxs, na.rm, interpolate, tiesC)
 } # weightedMedian()
 
 
