@@ -12,14 +12,14 @@ colMads_R <- function(x, na.rm=FALSE) {
   })
 }
 
-rowMads_center <- function(x, na.rm=FALSE) {
-  center <- rowMedians(x, na.rm=na.rm)
-  rowMads(x, center=center, na.rm=na.rm)
+rowMads_center <- function(x, rows=NULL, cols=NULL, na.rm=FALSE) {
+  center <- rowMedians(x, cols=cols, na.rm=na.rm)
+  rowMads(x, rows=rows, cols=cols, center=center, na.rm=na.rm)
 }
 
-colMads_center <- function(x, na.rm=FALSE) {
-  center <- colMedians(x, na.rm=na.rm)
-  colMads(x, center=center, na.rm=na.rm)
+colMads_center <- function(x, rows=NULL, cols=NULL, na.rm=FALSE) {
+  center <- colMedians(x, rows=rows, na.rm=na.rm)
+  colMads(x, rows=rows, cols=cols, center=center, na.rm=na.rm)
 }
 
 
