@@ -13,14 +13,14 @@ colSds_R <- function(x, na.rm=FALSE) {
 }
 
 
-rowSds_center <- function(x, na.rm=FALSE) {
-  center <- rowMeans(x, na.rm=na.rm)
-  rowSds(x, center=center, na.rm=na.rm)
+rowSds_center <- function(x, rows=NULL, cols=NULL, na.rm=FALSE) {
+  center <- rowWeightedMeans(x, cols=cols, na.rm=na.rm)
+  rowSds(x, rows=rows, cols=cols, center=center, na.rm=na.rm)
 }
 
-colSds_center <- function(x, na.rm=FALSE) {
-  center <- colMeans(x, na.rm=na.rm)
-  colSds(x, center=center, na.rm=na.rm)
+colSds_center <- function(x, rows=NULL, cols=NULL, na.rm=FALSE) {
+  center <- colWeightedMeans(x, rows=rows, na.rm=na.rm)
+  colSds(x, rows=rows, cols=cols, center=center, na.rm=na.rm)
 }
 
 
